@@ -5,7 +5,7 @@ package App::SpeedTest;
 use strict;
 use warnings;
 
-our $VERSION = "0.29";
+our $VERSION = "0.30";
 
 1;
 __END__
@@ -138,14 +138,14 @@ kilometers to the server.
 
  $ speedtest --list --country=IS
    1: 10661 - Tengir hf              Akureyri    1980.02 km
-   2: 21605 - Premis ehf             Reykjavk   2039.16 km
+   2: 21605 - Premis ehf             Reykjavík   2039.16 km
    3:  3684 - Nova                   Reykjavik   2039.16 km
    4:  6471 - Gagnaveita Reykjavikur Reykjavik   2039.16 km
    5: 10650 - Nova VIP               Reykjavik   2039.16 km
    6: 16148 - Hringidan              Reykjavik   2039.16 km
    7:  4818 - Siminn                 Reykjavik   2039.16 km
-   8: 17455 - Hringdu                Reykjavk   2039.16 km
-   9:  4141 - Vodafone               Reykjavk   2039.16 km
+   8: 17455 - Hringdu                Reykjavík   2039.16 km
+   9:  4141 - Vodafone               Reykjavík   2039.16 km
   10:  3644 - Snerpa                 Isafjordur  2192.27 km
 
 =item -p | --ping | --ping=40
@@ -165,7 +165,7 @@ Be very patient if running this with L</--all>.
    7: 26887 - Arxus NV             Brussels         173.04 km      64 ms
    8:  4812 - Universite Catholiq… Louvain-La-Neuv  186.87 km      70 ms
    9:  2848 - Cu.be Solutions      Diegem           166.33 km      75 ms
-  10: 12306 - VOO                  Lige            186.26 km      80 ms
+  10: 12306 - VOO                  Liège            186.26 km      80 ms
   11: 24261 - Une Nouvelle Ville…  Charleroi        217.48 km     147 ms
   12: 30594 - Orange Belgium       Evere            169.29 km     150 ms
 
@@ -499,7 +499,7 @@ personal use, but was asked to make it publicly available as application.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2022 H.Merijn Brand
+Copyright (C) 2014-2025 H.Merijn Brand
 
 This software is free; you can redistribute it and/or modify
 it under the same terms as Perl itself.
